@@ -23,14 +23,14 @@ def living_to_dead(population, lifespan=112):
     """
 
     assert len(population.shape) == 1, '生存人口の入力が異なります'
-    assert population.shape[0] == lifespan, '生存人口は0歳から最終年齢分まで入力してください'
+    assert population.shape[0] == lifespan + 1, '生存人口は0歳から最終年齢分まで入力してください'
 
     dead_population = []
 
-    for j in range(0, lifespan - 1):
+    for j in range(0, lifespan):
         dead_population.append(population[j] - population[j + 1])
     
-    dead_population.append(population[lifespan - 1])
+    dead_population.append(population[lifespan])
 
     dead_population = np.array(dead_population)
 
